@@ -940,6 +940,19 @@ test!(
 test!(
     indices2,
     r#"
+    indices("")
+    "#,
+    r#"
+    "abcde"
+    "#,
+    r#"
+    []
+    "#
+);
+
+test!(
+    indices3,
+    r#"
     indices(1)
     "#,
     r#"
@@ -951,7 +964,7 @@ test!(
 );
 
 test!(
-    indices3,
+    indices4,
     r#"
     indices([1,2])
     "#,
@@ -963,6 +976,19 @@ test!(
     "#
 );
 
+test!(
+    indices5,
+    r#"
+    indices([])
+    "#,
+    r#"
+    [0,1,2,3]
+    "#,
+    r#"
+    []
+    "#
+);
+
 test!(
     index1,
     r#"
@@ -1305,4 +1331,137 @@ test!(
 );
  */
 
+/*
+ TODO: Implement `env`
+test!(
+    env1,
+    r#"
+    $ENV.PAGER
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    "less"
+    "#
+);
+
+test!(
+    env2,
+    r#"
+    env.PAGER
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    "less"
+    "#
+);
+ */
+
+test!(
+    transpose1,
+    r#"
+    transpose
+    "#,
+    r#"
+    [[1], [2,3]]
+    "#,
+    r#"
+    [[1,2],[null,3]]
+    "#
+);
+
+test!(
+    bsearch1,
+    r#"
+    bsearch(0)
+    "#,
+    r#"
+    [0, 1]
+    "#,
+    r#"
+    0
+    "#
+);
+
+test!(
+    bsearch2,
+    r#"
+    bsearch(0)
+    "#,
+    r#"
+    [1,2,3]
+    "#,
+    r#"
+    -1
+    "#
+);
+
+test!(
+    bsearch3,
+    r#"
+    bsearch(4) as $ix | if $ix < 0 then .[-(1+$ix)] = 4 else . end
+    "#,
+    r#"
+    [1,2,3]
+    "#,
+    r#"
+    [1,2,3,4]
+    "#
+);
+
+test!(
+    string_interpolation1,
+    r#"
+    "The input was \(.), which is one less than \(.+1)"
+    "#,
+    r#"
+    42
+    "#,
+    r#"
+    "The input was 42, which is one less than 43"
+    "#
+);
+
+test!(
+    to_from_json1,
+    r#"
+    [.[]|tostring]
+    "#,
+    r#"
+    [1, "foo", ["foo"]]
+    "#,
+    r#"
+    ["1","foo","[\"foo\"]"]
+    "#
+);
+
+test!(
+    to_from_json2,
+    r#"
+    [.[]|tojson]
+    "#,
+    r#"
+    [1, "foo", ["foo"]]
+    "#,
+    r#"
+    ["1","\"foo\"","[\"foo\"]"]
+    "#
+);
+
+test!(
+    to_from_json3,
+    r#"
+    [.[]|tojson|fromjson]
+    "#,
+    r#"
+    [1, "foo", ["foo"]]
+    "#,
+    r#"
+    [1,"foo",["foo"]]
+    "#
+);
+
 // TODO: Add more
