@@ -259,3 +259,77 @@ test!(
     [1,3,4]
     "#
 );
+
+test!(
+    key_value_bind,
+    r#"
+    . as {$a:[$b]} | {$a,$b}
+    "#,
+    r#"
+    {"a":[1]}
+    "#,
+    r#"
+    {"a":[1],"b":1}
+    "#
+);
+
+test!(
+    key_query_bind,
+    r#"
+    . as {$a, (.b):[$b]} | {$a,$b}
+    "#,
+    r#"
+    {"a":[1], "b":"a"}
+    "#,
+    r#"
+    {"a":[1],"b":1}
+    "#
+);
+
+test!(
+    evaluation_order1,
+    r#"
+    [range(4)][0,1:][0,2]
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    0
+    1
+    2
+    3
+    "#
+);
+
+test!(
+    evaluation_order2,
+    r#"
+    .b[]."\(.a[])"
+    "#,
+    r#"
+    {"a":[0,1],"b":[{"0":1,"1":2},{"0":3,"1":4}]}
+    "#,
+    r#"
+    1
+    3
+    2
+    4
+    "#
+);
+
+test!(
+    evaluation_order3,
+    r#"
+    [range(4)][0,1:2,3]
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    [0,1]
+    [0,1,2]
+    [1]
+    [1,2]
+    "#
+);
